module.exports={A:{A:{"1":"B","2":"O F H lB","8":"E A"},B:{"1":"C N D I J K L KB P M R S YB U"},C:{"1":"0 1 2 3 4 5 6 7 8 9 D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M OB R S","2":"eB bB G Y O F H E A B C N kB sB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M R S YB U vB wB cB","2":"G Y O F H E A B C N D I J K","33":"L Z a b c d e f g"},E:{"1":"F H E A B C N D gB hB iB XB T Q mB nB","2":"G Y dB WB fB","33":"O"},F:{"1":"0 1 2 3 4 5 6 7 8 9 I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB EB GB HB IB JB X LB MB NB FB W V","2":"E B C oB pB qB rB T ZB tB Q"},G:{"1":"H D yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC","2":"WB uB aB TC","33":"xB"},H:{"2":"CC"},I:{"1":"M HC IC","2":"bB DC EC FC","8":"G GC aB"},J:{"1":"A","2":"F"},K:{"1":"DB","2":"A B C T ZB Q"},L:{"1":"U"},M:{"1":"OB"},N:{"1":"B","8":"A"},O:{"1":"JC"},P:{"1":"G KC LC MC NC OC XB PC QC"},Q:{"1":"RC"},R:{"1":"SC"},S:{"1":"jB"}},B:1,C:"Mutation Observer"};
