module.exports={A:{A:{"1":"B","16":"lB","132":"O F H E A"},B:{"1":"C N D I J K L KB P M R S YB U"},C:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M OB R S","132":"eB bB G Y O F H E A B C N D I J K L Z a b c d e f g h i kB sB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M R S YB U vB wB cB","132":"G Y O F H E A B C N D I J K L Z a b c d"},E:{"1":"A B C N D XB T Q mB nB","132":"G Y O F H E dB WB fB gB hB iB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB EB GB HB IB JB X LB MB NB FB W V","16":"E B C oB pB qB rB T ZB tB","132":"Q"},G:{"1":"D 2B 3B 4B 5B 6B 7B 8B 9B AC BC","132":"H WB uB aB TC xB yB zB 0B 1B"},H:{"132":"CC"},I:{"1":"M HC IC","132":"bB G DC EC FC GC aB"},J:{"132":"F A"},K:{"1":"DB","16":"A B C T ZB","132":"Q"},L:{"1":"U"},M:{"1":"OB"},N:{"1":"B","132":"A"},O:{"1":"JC"},P:{"1":"KC LC MC NC OC XB PC QC","132":"G"},Q:{"1":"RC"},R:{"1":"SC"},S:{"4":"jB"}},B:6,C:"localeCompare()"};
