module.exports={A:{A:{"2":"O F H E A B lB"},B:{"1":"KB P M R S YB U","2":"C N D I J K L"},C:{"2":"eB bB G Y O F H E A B C N D I J kB sB","4":"K L Z a","194":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M OB R S"},D:{"1":"X LB MB NB FB W V VB QB RB SB TB UB KB P M R S YB U vB wB cB","2":"0 1 2 3 4 5 6 7 8 9 G Y O F H E A B C N D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z","66":"AB BB CB DB EB PB GB HB IB JB"},E:{"2":"G Y O F H E A B C N D dB WB fB gB hB iB XB T Q mB nB"},F:{"1":"7 8 9 AB BB CB EB GB HB IB JB X LB MB NB FB W V","2":"E B C I J K L Z a b c d e f g h i j k l m n o p q r s t u v w oB pB qB rB T ZB tB Q","66":"0 1 2 3 4 5 6 x y z"},G:{"1":"D 7B 8B 9B AC BC","2":"H WB uB aB TC xB yB zB 0B 1B 2B 3B 4B 5B 6B"},H:{"2":"CC"},I:{"1":"M","2":"bB G DC EC FC GC aB HC IC"},J:{"2":"F A"},K:{"1":"DB","2":"A B C T ZB Q"},L:{"1":"U"},M:{"194":"OB"},N:{"2":"A B"},O:{"2":"JC"},P:{"1":"OC XB PC QC","2":"G KC LC MC NC"},Q:{"1":"RC"},R:{"2":"SC"},S:{"194":"jB"}},B:1,C:"inputmode attribute"};
