module.exports={A:{A:{"2":"O F H E A B lB"},B:{"1":"KB P M R S YB U","2":"C N D I","132":"J K L"},C:{"1":"6 7 8 9 AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M OB R S","2":"0 1 2 3 4 5 eB bB G Y O F H E A B C N D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z kB sB"},D:{"1":"EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M R S YB U vB wB cB","2":"0 1 2 3 4 5 6 7 8 9 G Y O F H E A B C N D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB","132":"BB CB DB"},E:{"1":"B C N D T Q mB nB","2":"G Y O F H E A dB WB fB gB hB iB","132":"XB"},F:{"1":"1 2 3 4 5 6 7 8 9 AB BB CB EB GB HB IB JB X LB MB NB FB W V","2":"E B C I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x oB pB qB rB T ZB tB Q","132":"0 y z"},G:{"1":"D 4B 5B 6B 7B 8B 9B AC BC","2":"H WB uB aB TC xB yB zB 0B 1B 2B","132":"3B"},H:{"2":"CC"},I:{"1":"M","2":"bB G DC EC FC GC aB HC IC"},J:{"2":"F A"},K:{"1":"DB","2":"A B C T ZB Q"},L:{"1":"U"},M:{"1":"OB"},N:{"2":"A B"},O:{"132":"JC"},P:{"1":"NC OC XB PC QC","2":"G KC LC","132":"MC"},Q:{"1":"RC"},R:{"2":"SC"},S:{"132":"jB"}},B:5,C:"CSS justify-content: space-evenly"};
