module.exports={A:{A:{"2":"O F H E A B lB"},B:{"1":"KB P M R S YB U","2":"C N D I J K L"},C:{"2":"0 1 2 3 4 5 6 7 8 9 eB bB G Y O F H E A B C N D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M OB R S kB sB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 G Y O F H E A B C N D I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB PB GB HB IB JB X LB MB NB FB W V VB QB RB SB TB UB KB P M R S YB U vB wB cB"},E:{"1":"G Y O F H E A B C dB WB fB gB hB iB XB T Q","2":"N D mB nB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C I J K L Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB EB GB HB IB JB X LB MB NB FB W V qB rB T ZB tB Q","2":"E oB pB"},G:{"1":"H WB uB aB TC xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B","2":"D 8B 9B AC BC"},H:{"2":"CC"},I:{"1":"bB G M DC EC FC GC aB HC IC"},J:{"1":"F A"},K:{"1":"B C DB T ZB Q","2":"A"},L:{"1":"U"},M:{"2":"OB"},N:{"2":"A B"},O:{"1":"JC"},P:{"1":"G KC LC MC NC OC XB PC QC"},Q:{"1":"RC"},R:{"1":"SC"},S:{"2":"jB"}},B:7,C:"Web SQL Database"};
